# survInsights
_survinsights_ is a framework for interpreting survival models

## Quick description
_survinsights_ is a Python 3 package 


## Notebook tutorial

The Jupyter notebooks in folder "examples" give useful tutorials of how to use the framework